@@ -1,43 +1,19 @@
 package YAML;
-use YAML::Base -base;
-require 5.6.1;
-our $VERSION = '0.49_70';
-our @EXPORT = qw'Dump Load';
-our @EXPORT_OK = qw'freeze thaw DumpFile LoadFile Bless Blessed';
 
-# This line is here to convince "autouse" into believing we are autousable.
-sub can {
-    ($_[1] eq 'import' and caller()->isa('autouse'))
-        ? \&Exporter::import        # pacify autouse's equality test
-        : $_[0]->SUPER::can($_[1])  # normal case
-}
+use 5.006001;
+use strict;
+use warnings;
+use YAML::Base;
+use YAML::Node; # XXX This is a temp fix for Module::Build
 
-# XXX This value nonsense needs to go.
+our $VERSION   = '0.69_01';
+our @ISA       = 'YAML::Base';
+our @EXPORT    = qw{ Dump Load };
+our @EXPORT_OK = qw{ freeze thaw DumpFile LoadFile Bless Blessed };
+
+# XXX This VALUE nonsense needs to go.
 use constant VALUE => "\x07YAML\x07VALUE\x07";
 
-# Global Options are an idea taken from Data::Dumper. Really they are just
-# sugar on top of real OO properties. They make the simple Dump/Load API
-# easy to configure.
-
-# New global options
-our $SpecVersion = '1.0';
-our $LoaderClass = '';
-our $DumperClass = '';
-
-# Legacy global options
-our $Indent         = 2;
-our $UseHeader      = 1;
-our $UseVersion     = 0;
-our $SortKeys       = 1;
-our $AnchorPrefix   = '';
-our $UseCode        = 0;
-our $DumpCode       = '';
-our $LoadCode       = '';
-our $UseBlock       = 0;
-our $UseFold        = 0;
-our $CompressSeries = 1;
-our $UseAliases     = 1;
-
 # YAML Object Properties
 field dumper_class => 'YAML::Dumper';
 field loader_class => 'YAML::Loader';
@@ -47,53 +23,64 @@ field loader_object =>
     -init => '$self->init_action_object("loader")';
 
 sub Dump {
-    my $yaml = 'YAML'->new;
-    $yaml->dumper_class($DumperClass)
-        if $DumperClass;
+    my $yaml = YAML->new;
+    $yaml->dumper_class($YAML::DumperClass)
+        if $YAML::DumperClass;
     return $yaml->dumper_object->dump(@_);
 }
 
 sub Load {
     my $yaml = YAML->new;
-    $yaml->loader_class($LoaderClass)
-        if $LoaderClass;
+    $yaml->loader_class($YAML::LoaderClass)
+        if $YAML::LoaderClass;
     return $yaml->loader_object->load(@_);
 }
 
-sub DumpFile {
-    my $filename = shift;
-    local $/ = "\n"; # reset special to "sane"
-    my $mode = '>';
-    if ($filename =~ /^\s*(>{1,2})\s*(.*)$/) {
-        ($mode, $filename) = ($1, $2);
-    }
-    open my $OUT, $mode, $filename
-      or $self->die("Can't open '$filename' for output:\n$!");
-    print $OUT Dump(@_);
-}
-
 {
     no warnings 'once';
     # freeze/thaw is the API for Storable string serialization. Some
     # modules make use of serializing packages on if they use freeze/thaw.
     *freeze = \ &Dump;
     *thaw   = \ &Load;
-    # This 
+}
+
+sub DumpFile {
+    my $OUT;
+    my $filename = shift;
+    if (ref $filename eq 'GLOB') {
+        $OUT = $filename;
+    }
+    else {
+        my $mode = '>';
+        if ($filename =~ /^\s*(>{1,2})\s*(.*)$/) {
+            ($mode, $filename) = ($1, $2);
+        }
+        open $OUT, $mode, $filename
+          or YAML::Base->die('YAML_DUMP_ERR_FILE_OUTPUT', $filename, $!);
+    }  
+    local $/ = "\n"; # reset special to "sane"
+    print $OUT Dump(@_);
 }
 
 sub LoadFile {
+    my $IN;
     my $filename = shift;
-    open my $IN, $filename
-      or $self->die("Can't open '$filename' for input:\n$!");
+    if (ref $filename eq 'GLOB') {
+        $IN = $filename;
+    }
+    else {
+        open $IN, $filename
+          or YAML::Base->die('YAML_LOAD_ERR_FILE_INPUT', $filename, $!);
+    }
     return Load(do { local $/; <$IN> });
-}   
+}
 
 sub init_action_object {
     my $self = shift;
     my $object_class = (shift) . '_class';
     my $module_name = $self->$object_class;
     eval "require $module_name";
-    die "Error in require $module_name - $@"
+    $self->die("Error in require $module_name - $@")
         if $@ and "$@" !~ /Can't locate/;
     my $object = $self->$object_class->new;
     $object->set_global_options;
@@ -111,12 +98,36 @@ sub Blessed {
 }
 sub global_object { $global }
 
+1;
+
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 YAML - YAML Ain't Markup Language (tm)
 
+=head1 NOTE
+
+This module has been released to CPAN as YAML::Old, and soon YAML.pm
+will be changed to just be a frontend interface module for all the
+various Perl YAML implementation modules, including YAML::Old.
+
+If you want robust and fast YAML processing using the normal Dump/Load
+API, please consider switching to YAML::XS. It is by far the best Perl
+module for YAML at this time. It requires that you have a C compiler,
+since it is written in C.
+
+If you really need to use this version of YAML.pm it will always be
+available as YAML::Old.
+
+If you don't care which YAML module use, as long as it's the best one
+installed on your system, use YAML::Any.
+
+The rest of this documentation is left unchanged, until YAML.pm is
+switched over to the new UI-only version.
+
 =head1 SYNOPSIS
 
     use YAML;
@@ -252,11 +263,11 @@ YAML specification in pure Perl. This may not be the fastest or most
 stable module though. Currently, YAML.pm has lots of known bugs. It is
 mostly a great tool for dumping Perl data structures to a readable form.
 
-=item YAML::Simple
+=item YAML::Lite
 
-The point of YAML::Simple is to strip YAML down to the 90% that people
+The point of YAML::Lite is to strip YAML down to the 90% that people
 use most and offer that in a small, fast, stable, pure Perl form.
-YAML::Simple will simply die when it is asked to do something it can't.
+YAML::Lite will simply die when it is asked to do something it can't.
 
 =item YAML::Syck
 
@@ -265,6 +276,9 @@ programming language (and also Python, PHP and Pugs). YAML::Syck is the
 Perl binding to C<libsyck>. It should be very fast, but may have
 problems of its own. It will also require C compilation.
 
+NOTE: Audrey Tang has actually completed this module and it works great
+      and is 10 times faster than YAML.pm.
+
 =back
 
 In the future, there will likely be even more YAML modules. Remember,
@@ -411,6 +425,23 @@ By the way, YAML can use any number of characters for indentation at any
 level. So if you are editing YAML by hand feel free to do it anyway that
 looks pleasing to you; just be consistent for a given level.
 
+=item SortKeys
+
+Default is 1. (true)
+
+Tells YAML.pm whether or not to sort hash keys when storing a document. 
+
+YAML::Node objects can have their own sort order, which is usually what
+you want. To override the YAML::Node order and sort the keys anyway, set
+SortKeys to 2.
+
+=item Stringify
+
+Default is 0. (false)
+
+Objects with string overloading should honor the overloading and dump the
+stringification of themselves, rather than the actual object's guts.
+
 =item UseHeader
 
 Default is 1. (true)
@@ -428,16 +459,6 @@ separator/header.
 
     --- %YAML:1.0
 
-=item SortKeys
-
-Default is 1. (true)
-
-Tells YAML.pm whether or not to sort hash keys when storing a document. 
-
-YAML::Node objects can have their own sort order, which is usually what
-you want. To override the YAML::Node order and sort the keys anyway, set
-SortKeys to 2.
-
 =item AnchorPrefix
 
 Default is ''.
@@ -734,7 +755,8 @@ To run ysh, (assuming you installed it along with YAML.pm) simply type:
 
     ysh [options]
 
-Please read L<ysh> for the full details. There are lots of options.
+Please read the C<ysh> documentation for the full details. There are
+lots of options.
 
 =head1 BUGS & DEFICIENCIES
 
@@ -742,7 +764,8 @@ If you find a bug in YAML, please try to recreate it in the YAML Shell
 with logging turned on ('ysh -L'). When you have successfully reproduced
 the bug, please mail the LOG file to the author (ingy@cpan.org).
 
-WARNING: This is *ALPHA* code. 
+WARNING: This is still *ALPHA* code. Well, most of this code has been
+around for years...
 
 BIGGER WARNING: YAML.pm has been slow in the making, but I am committed
 to having top notch YAML tools in the Perl world. The YAML team is close
@@ -762,9 +785,15 @@ L<http://www.yaml.org/spec/> is the YAML 1.0 specification.
 
 L<http://yaml.kwiki.org> is the official YAML wiki.
 
+=head1 SEE ALSO
+
+See YAML::Syck. Fast!
+
 =head1 AUTHOR
 
-Ingy döt Net <ingy@cpan.org> is resonsible for YAML.pm.
+Ingy döt Net <ingy@cpan.org>
+
+is resonsible for YAML.pm.
 
 The YAML serialization language is the result of years of collaboration
 between Oren Ben-Kiki, Clark Evans and Ingy döt Net. Several others
@@ -772,8 +801,11 @@ have added help along the way.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005. Ingy döt Net. All rights reserved.
-Copyright (c) 2001, 2002, 2005. Brian Ingerson. All rights reserved.
+Copyright (c) 2005, 2006, 2008. Ingy döt Net.
+
+Copyright (c) 2001, 2002, 2005. Brian Ingerson.
+
+Some parts copyright (c) 2009 Adam Kennedy
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
